@@ -1,6 +1,6 @@
 """Response helper functions for FastAPI routes."""
 
-from typing import Any, Dict, Type
+from typing import Any, Dict, Optional, Type
 
 from fastapi.encoders import jsonable_encoder
 from fastapi.responses import JSONResponse, Response
@@ -17,7 +17,7 @@ def return_response(
     status_code: int,
     response_class: Type[Response],
     return_json_directly: bool = False,
-    headers: Dict[int, Dict] = None,
+    headers: Optional[Dict[int, Dict[Any, Any]]] = None,
     no_cache: bool = True,
 ) -> Response:
     """Build a FastAPI response with standard success/error wrapping.
@@ -76,7 +76,7 @@ def return_json_response(
     data: Any,
     status_code: int,
     return_json_directly: bool = False,
-    headers: Dict[int, Dict] = None,
+    headers: Optional[Dict[int, Dict[Any, Any]]] = None,
     no_cache: bool = True,
 ) -> Response:
     """Convenience wrapper for return_response using JSONResponse.
