@@ -7,7 +7,19 @@ __all__ = ("add_query_param",)
 
 
 def add_query_param(url: str, params: Dict[str, Any]) -> str:
-    """Return ``url`` with additional query string parameters."""
+    """Add or update query parameters in a URL.
+
+    This function takes a URL and a dictionary of parameters, then adds the
+    parameters to the URL's query string. If a parameter already exists,
+    its value is updated.
+
+    Args:
+        url: The original URL.
+        params: A dictionary of query parameters to add or update.
+
+    Returns:
+        The new URL with the updated query parameters.
+    """
 
     url_parts = urlparse(url)
     query_params = parse_qs(url_parts.query)
