@@ -41,7 +41,7 @@ def get_list(
     - Flexible output formats (models, dicts, or full metadata)
 
     The function builds a query in stages:
-    1. Applies joins and pre-conditions
+    1. Applies joins and static filters
     2. Processes dynamic filters from ctx.current_query
     3. Applies free-text search across ctx.searchable_columns
     4. Deduplicates by ctx.primary_column if ctx.unique=True
@@ -54,7 +54,7 @@ def get_list(
             - db: Active SQLAlchemy database session
             - model: SQLAlchemy model class to query
             - joins: Optional join configurations
-            - pre_conditions: Optional SQLAlchemy filter expressions
+            - static_filters: Optional SQLAlchemy filter expressions that always apply
             - filters: Optional filter definitions
             - searchable_columns: Optional columns for free-text search
             - exact_search: Enable exact phrase matching (default: False)
@@ -115,8 +115,7 @@ def get_list(
         ...         }
         ...     ],
         ...     searchable_columns=[User.name, User.email],
-        ...     pre_conditions=[User.deleted_at.is_(None)]
-        ... )
+        ... ).add_static_filter(User.deleted_at.is_(None))
         >>> 
         >>> result = get_list(ctx)
         >>> print(f"Total users: {result.payload.total_row}")
@@ -148,7 +147,7 @@ def get_list(
     joins = ctx.joins or []
     filters = ctx.filters or []
     searchable_columns = ctx.searchable_columns or []
-    pre_conditions = ctx.pre_conditions or []
+    static_filters = ctx.static_filters or []
     options = ctx.options or []
     return_as_dict_parameters = ctx.return_as_dict_parameters or {}
 
@@ -171,8 +170,8 @@ def get_list(
         main_query = main_query.join(**join_item)
         count_query = count_query.join(**join_item)
 
-    main_query = main_query.where(*pre_conditions)
-    count_query = count_query.where(*pre_conditions)
+    main_query = main_query.where(*static_filters)
+    count_query = count_query.where(*static_filters)
 
     # Initialize rows and conditions
     conditions = []
@@ -328,7 +327,7 @@ def get_list(
             available_filters: AvailableFilters = (
                 get_filters_value(
                     db=ctx.db,
-                    pre_conditions=pre_conditions,
+                    pre_conditions=static_filters,
                     joins=joins,
                     filters=filters,
                     names_conditions=names_conditions,
