@@ -9,6 +9,7 @@ from typing import Any, Callable, Type
 from uuid import UUID
 
 from pydantic import BaseModel
+from sqlalchemy import and_
 from sqlalchemy.orm import Session
 
 from .schema import AvailableFilterType, ColumnsLogic
@@ -30,7 +31,7 @@ class GetListContext:
         db: Active SQLAlchemy database session for executing queries.
         model: SQLAlchemy model class to query (must inherit from DeclarativeBase).
         joins: List of join configurations for related tables (use add_join()).
-        pre_conditions: List of SQLAlchemy filter expressions to always apply (use add_pre_condition()).
+        static_filters: List of SQLAlchemy filter expressions that always apply (use add_static_filter()).
         filters: List of filter definitions for dynamic filtering (use add_filter()).
         searchable_columns: List of SQLAlchemy column objects to search across (use add_searchable_columns()).
         exact_search: If True, search matches exact phrases. If False, uses fuzzy matching (use set_exact_search()).
@@ -112,7 +113,7 @@ class GetListContext:
         
         # Initialize with defaults - use builder methods to customize
         self.joins: list[dict[str, Any]] = []
-        self.pre_conditions: list[Any] = []
+        self.static_filters: list[Any] = []
         self.filters: list[dict[str, Any]] = []
         self.searchable_columns: list[Any] = []
         self.exact_search: bool = False
@@ -354,20 +355,26 @@ class GetListContext:
         self.joins.append(join_config)
         return self
     
-    def add_pre_condition(self, condition: Any) -> "GetListContext":
-        """Add a pre-condition filter that always applies to the query.
+    def add_static_filter(self, condition: Any) -> "GetListContext":
+        """Add a static filter condition that always applies to the query.
+        
+        You can call this method multiple times to add more static filters.
+        All static filters are combined with AND logic.
         
         Args:
-            condition: SQLAlchemy filter expression
+            condition: SQLAlchemy filter expression to always apply
         
         Returns:
             GetListContext: Self for method chaining.
         
         Example:
-            >>> ctx.add_pre_condition(User.deleted_at.is_(None))
-            >>> ctx.add_pre_condition(User.is_active == True)
+            >>> # Add single condition
+            >>> ctx.add_static_filter(User.deleted_at.is_(None))
+            >>> 
+            >>> # Chain multiple calls (AND combined)
+            >>> ctx.add_static_filter(User.deleted_at.is_(None)).add_static_filter(User.is_active == True)
         """
-        self.pre_conditions.append(condition)
+        self.static_filters.append(condition)
         return self
     
     def add_searchable_columns(self, *columns: Any) -> "GetListContext":
