@@ -96,7 +96,7 @@ def select_condition_maker(
 
     # if no conditions, return a no-op true clause
     if not conditions:
-        return True  # or `text('TRUE')` in SQLAlchemy
+        return literal(True)
 
     return logic_fn(*conditions)
 
@@ -124,7 +124,7 @@ def number_condition_maker(
     logic_function = {
         "or": or_,
         "and": and_,
-    }.get(columns_logic)
+    }.get(columns_logic, and_)
 
     value_min = values.get("min")
     value_max = values.get("max")
@@ -136,6 +136,8 @@ def number_condition_maker(
         return logic_function(*[column <= value_max for column in columns])
     elif value_min is not None and value_max is None:
         return logic_function(*[column >= value_min for column in columns])
+    else:
+        return None
 
 
 def date_condition_maker(
@@ -157,15 +159,15 @@ def date_condition_maker(
         A SQLAlchemy boolean expression for the date range condition,
         or None if no valid range is specified.
     """
-    value_min: datetime = values.get("min")
-    value_max: datetime = values.get("max")
+    value_min: datetime | None = values.get("min")
+    value_max: datetime | None = values.get("max")
 
-    columns = filter_item.get("columns")
+    columns = filter_item.get("columns", [])
     columns_logic = filter_item.get("columns_logic", "or")
     logic_function = {
         "or": or_,
         "and": and_,
-    }.get(columns_logic)
+    }.get(columns_logic, and_)
 
     if value_min is not None and value_max is not None:
         return logic_function(
@@ -177,6 +179,8 @@ def date_condition_maker(
         )
     elif value_min is not None and value_max is None:
         return logic_function(*[column >= value_min for column in columns])
+    else:
+        return None
 
 
 def make_condition(
