@@ -188,7 +188,8 @@ class AsyncRedisStreamer(CommonMethods):
                 payload={"channel": channel, "message_name": message.name},
             )
             client = await self._get_client()
-            await client.xadd(channel, message.get_json_encoded())
+            fields = message.get_json_encoded()
+            await client.xadd(channel, fields)  # type: ignore[arg-type]
             footprint.leave(
                 log_type="debug",
                 controller=controller,
@@ -700,7 +701,6 @@ class AsyncRedisStreamer(CommonMethods):
             tasks[(channel, listener, group)] = (task, task_args)
 
         while True:
-            await asyncio.sleep(60)
             for key, (task, args) in list(tasks.items()):
                 if task.done():
                     try:
@@ -729,6 +729,8 @@ class AsyncRedisStreamer(CommonMethods):
                     new_task = asyncio.create_task(self._consume_loop(*args))
                     tasks[key] = (new_task, args)
 
+            await asyncio.sleep(60)
+
     @retry_wrapper()
     async def maintain_ledgers(self) -> None:
         """Clean up expired deduplication ZSET entries asynchronously.
@@ -786,7 +788,6 @@ class AsyncRedisStreamer(CommonMethods):
 
         while True:
             try:
-                await asyncio.sleep(self._ledger_cleanup_interval / 1000)
                 await self.maintain_ledgers()
                 self._last_ledger_cleanup = self._server_now_ms()
             except REDIS_EXCEPTIONS as e:
@@ -808,16 +809,18 @@ class AsyncRedisStreamer(CommonMethods):
                     payload={"error": exception_to_dict(e)},
                 )
                 await asyncio.sleep(60)
+            else:
+                await asyncio.sleep(self._ledger_cleanup_interval / 1000)
 
     @retry_wrapper()
     async def cleanup_channels(self) -> None:
-        """Clean up old dedup entries from channels based on retention period.
+        """Clean up old messages from channels based on retention period.
 
         Description:
             For each registered channel with a retention configuration,
-            removes deduplication entries older than the retention window.
+            removes messages older than the retention window using XTRIM.
             This helps manage memory usage for high-throughput channels by
-            preventing unbounded growth of tracking data.
+            preventing unbounded growth of stream data.
 
         Raises:
             Exception: Re-raises Redis exceptions after reconnection attempt.
@@ -834,21 +837,29 @@ class AsyncRedisStreamer(CommonMethods):
                 continue
 
             try:
-                group = self._group_name(channel, self.listener_name)
-                processed_key = self._processed_zset_key(channel, group)
                 cutoff = now_ms - retention
-
-                removed_count = await client.zremrangebyscore(
-                    processed_key, min="-inf", max=f"({cutoff}"
+                
+                # Trim old messages from the stream based on retention
+                # MINID removes all messages with ID lower than the cutoff
+                trimmed_count = await client.xtrim(
+                    channel, minid=cutoff, approximate=True
                 )
 
-                if removed_count:
+                if trimmed_count:
                     footprint.leave(
                         log_type="info",
-                        message=f"Cleaned up {removed_count} old dedup entries from channel {channel}",
+                        message=f"Trimmed {trimmed_count} old messages from channel {channel}",
                         controller=controller,
                         subject="Async channel cleanup",
-                        payload={"channel": channel, "removed_count": removed_count},
+                        payload={"channel": channel, "trimmed_count": trimmed_count},
+                    )
+                else:
+                    footprint.leave(
+                        log_type="debug",
+                        message=f"No old messages to trim for channel {channel}",
+                        controller=controller,
+                        subject="Channel cleanup",
+                        payload={"channel": channel},
                     )
 
             except REDIS_EXCEPTIONS as e:
@@ -881,9 +892,14 @@ class AsyncRedisStreamer(CommonMethods):
         """
         controller = f"{__name__}.AsyncRedisStreamer._cleanup_channels_loop"
 
+        footprint.leave(
+            log_type="info",
+            message="Launching channel cleanup thread",
+            controller=controller,
+            subject="Channel cleanup thread started",
+        )
         while True:
             try:
-                await asyncio.sleep(cleanup_interval)
                 await self.cleanup_channels()
             except Exception as e:
                 footprint.leave(
@@ -894,6 +910,8 @@ class AsyncRedisStreamer(CommonMethods):
                     payload={"error": exception_to_dict(e)},
                 )
                 await asyncio.sleep(60)
+            else:
+                await asyncio.sleep(cleanup_interval)
 
     async def cleanup(self) -> None:
         """Clean up async resources and stop all background tasks.
