@@ -1,7 +1,7 @@
 import json
 import threading
 import time
-from typing import Any, Dict, Optional, Self
+from typing import Any, Dict, Literal, Optional, Self
 
 from redis import Redis
 
@@ -44,6 +44,7 @@ class RedisStreamer(CommonMethods):
 
         self._redis_client: Redis = self._redis_instance.get_redis_client()
         self._maintenance_thread_started = False
+        self._cleanup_channels_thread_started = False
 
     def _reconnect(self) -> None:
         """Attempt to reconnect to Redis with exponential backoff retries.
@@ -123,7 +124,7 @@ class RedisStreamer(CommonMethods):
         try:
             groups = self._redis_client.xinfo_groups(channel_name)
             return any(
-                group["name"].decode("utf-8") == consumer_group for group in groups
+                group["name"].decode("utf-8") == consumer_group for group in groups  # type: ignore
             )
         except REDIS_EXCEPTIONS as e:
             footprint.leave(
@@ -419,6 +420,10 @@ class RedisStreamer(CommonMethods):
             if not msgs:
                 return
 
+            # Ensure we have a proper list structure
+            if not isinstance(msgs, list) or len(msgs) == 0:
+                return
+                
             _, batch = msgs[0]
             processed_key = self._processed_zset_key(channel, consumer_group)
             now_ms = self._server_now_ms()
@@ -628,7 +633,11 @@ class RedisStreamer(CommonMethods):
                 time.sleep(5)
 
     def persist_consume(
-        self, rest_time: float = 0.1, block_time: float = 5.0, count: int = 32
+        self,
+        rest_time: float = 0.1,
+        block_time: float = 5.0,
+        count: int = 32,
+        cleanup_interval: float = 300.0,
     ) -> None:
         """Continuously consume messages from all subscribed channels.
 
@@ -646,6 +655,8 @@ class RedisStreamer(CommonMethods):
                 messages in each XREADGROUP call. Defaults to 5.0.
             count (int, optional): Maximum messages to read per batch from
                 each channel. Defaults to 32.
+            cleanup_interval (float, optional): Seconds between channel cleanup
+                runs for retention management. Defaults to 300.0 (5 minutes).
 
         Returns:
             None
@@ -657,6 +668,15 @@ class RedisStreamer(CommonMethods):
             mt.start()
             self._maintenance_thread_started = True
 
+        if self._channel_retention and not self._cleanup_channels_thread_started:
+            ct = threading.Thread(
+                target=self._cleanup_channels_loop,
+                args=(cleanup_interval,),
+                daemon=True,
+            )
+            ct.start()
+            self._cleanup_channels_thread_started = True
+
         threads = {}
         for channel, listener, group in self._subscriptions:
             thread_args = (channel, listener, group, block_time, count, rest_time)
@@ -669,7 +689,6 @@ class RedisStreamer(CommonMethods):
             threads[(channel, listener, group)] = (t, thread_args)
 
         while True:
-            time.sleep(60)
             for key, (thread, args) in list(threads.items()):
                 if not thread.is_alive():
                     footprint.leave(
@@ -685,6 +704,8 @@ class RedisStreamer(CommonMethods):
                     new_thread.start()
                     threads[key] = (new_thread, args)
 
+            time.sleep(60)
+
     @retry_wrapper()
     def maintain_ledgers(self) -> None:
         """Clean up expired deduplication ZSET entries synchronously.
@@ -739,7 +760,6 @@ class RedisStreamer(CommonMethods):
 
         while True:
             try:
-                time.sleep(self._ledger_cleanup_interval / 1000)
                 self.maintain_ledgers()
                 self._last_ledger_cleanup = self._server_now_ms()
             except REDIS_EXCEPTIONS as e:
@@ -761,6 +781,108 @@ class RedisStreamer(CommonMethods):
                     payload={"error": exception_to_dict(e)},
                 )
                 time.sleep(60)
+            else:
+                time.sleep(self._ledger_cleanup_interval / 1000)
+
+    @retry_wrapper()
+    def cleanup_channels(self) -> None:
+        """Clean up old messages from channels based on retention period.
+
+        Description:
+            For each registered channel with a retention configuration,
+            removes messages older than the retention window using XTRIM.
+            This helps manage memory usage for high-throughput channels by
+            preventing unbounded growth of stream data.
+
+        Raises:
+            Exception: Re-raises Redis exceptions after reconnection attempt.
+
+        Returns:
+            None
+        """
+        controller = f"{__name__}.RedisStreamer.cleanup_channels"
+        now_ms = self._server_now_ms()
+
+        for channel, retention in self._channel_retention.items():
+            if retention is None:
+                continue
+
+            try:
+                cutoff = now_ms - retention
+                
+                # Trim old messages from the stream based on retention
+                # MINID removes all messages with ID lower than the cutoff
+                trimmed_count = self._redis_client.xtrim(
+                    channel, minid=cutoff, approximate=True
+                )
+
+                if trimmed_count:
+                    footprint.leave(
+                        log_type="info",
+                        message=f"Trimmed {trimmed_count} old messages from channel {channel}",
+                        controller=controller,
+                        subject="Channel cleanup",
+                        payload={"channel": channel, "trimmed_count": trimmed_count},
+                    )
+                else:
+                    footprint.leave(
+                        log_type="debug",
+                        message=f"No old messages to trim for channel {channel}",
+                        controller=controller,
+                        subject="Channel cleanup",
+                        payload={"channel": channel},
+                    )
+
+            except REDIS_EXCEPTIONS as e:
+                self._reconnect()
+                raise e
+            except Exception as e:
+                footprint.leave(
+                    log_type="error",
+                    subject="Channel cleanup error",
+                    controller=controller,
+                    message=f"Error cleaning up channel {channel}",
+                    payload={"error": exception_to_dict(e), "channel": channel},
+                )
+
+    def _cleanup_channels_loop(self, cleanup_interval: float = 300.0) -> None:
+        """Background thread for periodic channel cleanup.
+
+        Description:
+            Runs continuously, sleeping for the cleanup interval and then
+            triggering channel cleanup to remove old deduplication entries
+            based on retention policies. This thread manages long-term memory
+            usage for high-volume channels.
+
+        Args:
+            cleanup_interval (float, optional): Seconds between cleanup runs.
+                Defaults to 300.0 (5 minutes).
+
+        Returns:
+            None
+        """
+        controller = f"{__name__}.RedisStreamer._cleanup_channels_loop"
+
+        footprint.leave(
+            log_type="info",
+            message="Launching channel cleanup thread",
+            controller=controller,
+            subject="Channel cleanup thread started",
+        )
+        while True:
+            try:
+                self.cleanup_channels()
+            except Exception as e:
+                footprint.leave(
+                    log_type="error",
+                    subject="Cleanup channels loop error",
+                    controller=controller,
+                    message="Error in cleanup channels loop",
+                    payload={"error": exception_to_dict(e)},
+                )
+                time.sleep(60)
+            else:
+                time.sleep(cleanup_interval)
 
     def cleanup(self) -> None:
         """Clean up resources on shutdown.
@@ -829,7 +951,7 @@ class RedisStreamer(CommonMethods):
         """
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb) -> Optional[bool]:
+    def __exit__(self, exc_type, exc_val, exc_tb) -> Literal[False]:
         """Context manager exit point with automatic cleanup.
 
         Description:
